wotb is a crate making “Web of Trust” computations for
the Runiter project.
It defines a trait representing a Web of Trust and allow to do calculations on it.
It also contains an “legacy” implementation translated from the original C++ code.
Web of Trust tests are translated from duniter/wotb Javascript test.
Re-exports
pub use data::NodeId;pub use data::WebOfTrust;
Modules
- data
- Provide data structures to manage web of trusts.
LegacyWebOfTrustis almost a translation of the legacy C++ coden whileRustyWebOfTrustis a brand new implementation with a more “rusty” style. - operations
- Provide operation traits and implementations on
WebOfTrustobjects.